import {environment} from '../../../environments/environment';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {Component, OnInit, Injector} from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {ActivatedRoute} from '@angular/router';
import * as echarts from 'echarts';
import * as $ from 'jquery';

@Component({
  selector: 'app-report',
  templateUrl: './report.component.html',
  styles: []
})
export class ReportComponent implements OnInit {
  [x: string]: any;

  constructor(
    public injector: Injector,
    public http: HttpClient,
    public activeRoute: ActivatedRoute,
    public msgSrv: NzMessageService
  ) {
    for (let index = 0; index < 30; index++) {
      this.sensorArr.push(index);
    }
  }

  public echartOption = {
    title: {
      text: '',
      // subtext: '12月份',
      left: 'center'
    },
    tooltip: {
      trigger: 'axis'
    },
    legend: {
      data: [],
      orient: 'vertical',
      right: 40,
      top: 5,
      bottom: 20
    },
    toolbox: {
      show: false,
      feature: {
        dataZoom: {
          yAxisIndex: 'none'
        },
        dataView: {readOnly: false},
        magicType: {type: ['line', 'bar']},
        restore: {},
        saveAsImage: {}
      }
    },
    xAxis: {
      type: 'category',
      // boundaryGap: false,
      data: [],
      name: ''
    },
    yAxis: {
      type: 'value',
      name: ''

    },
    series: [
      //      {
      //        smooth: true,
      //        type: 'line',
      //        data: [],
      //        name: '',
      //        itemStyle: {
      //          normal: {
      //            barBorderRadius: [10, 10, 10, 10]
      //          }
      //        }
      //      }
    ]
  };

  sensorArr: any = [];
  
  ngOnInit() {
    this.activeRoute.queryParams.subscribe(params => {
      const items = JSON.parse(params.items);
      const query = params;
      this.http.get(environment.SERVER_BASH_URL + 'report/compare', {params: query}).subscribe((res: any) => {
        if (res.code === 0) {
          this.msgSrv.error(res.message);
        } else {
          const option = this.echartOption;
          const datas = res.data.datas;
          const times = res.data.times
          const sensors = res.data.sensors
          option.xAxis.data = times;
          option.xAxis.name = query.xAxisName;
          for (let index = 0; index < sensors.length; index++) {
            let sensorKey = sensors[index];
            let split = sensorKey.split('-');
            option.title.text = split[1] + query.label + '历走势图';
            option.yAxis.name = split[2] && split[2] != 'null' ? split[2] : '';
            option.series = [];
            option.legend.data = [];

            for (let i = 0; i < items.length; i++) {
              const legendName = items[i].formatTime + query.label + (items[i].mac ? items[i].deviceName : items[i].monitorPointName);
              option.legend.data[i] = legendName;
              const seriesData = datas[i]['data' + i][0][sensorKey];
              option.series.push({
                data: seriesData,
                smooth: true,
                type: 'line',
                name: legendName
              });
            }
            const myChart = echarts.init(document.getElementById('mydiv' + index));
            myChart.setOption(option, true);
            window.onresize = myChart.resize;
          }
          this.sensorArr.forEach(i => {
            if (i >= sensors.length) {
              $('#mydiv' + i).remove();
            }
          });
        }
      });
    });
  }
}
